---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2016-12-01;225
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20161202&codiceRedaz=16G00238&dataVigenza=20251104
dataGU: 20161202
codiceRedaz: 16G00238
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 22 ottobre 2016, n. 193, recante disposizioni urgenti in materia fiscale e per il finanziamento di esigenze indifferibili. (16G00238)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 22 ottobre 2016, n. 193, recante disposizioni urgenti in materia fiscale e per il finanziamento di esigenze indifferibili, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

